/*---------------------------------------------------------------------------
Program :		  ImagePanel.cpp	Version 1.1
					    TImagePanel Component for BCB1 and BCB3/4/5
Author :		  Michel Leunen
Email :			  leu@rtbf.be
					    Michel@leunen.com
Date :			  04/08/1998
Description :	Component for Borland C++ Builder V1 that draws a bitmap on a
					    TPanel. The image could be stretchd, tiled or drawn alone.
*/
//---------------------------------------------------------------------------
#include <vcl\vcl.h>
#pragma hdrstop

#include "ImagePanel.h"
#include <windows.h>
//---------------------------------------------------------------------------
static inline TImagePanel *ValidCtrCheck()
{
	return new TImagePanel(NULL);
}
//---------------------------------------------------------------------------
__fastcall TImagePanel::TImagePanel(TComponent* Owner)
	: TGraphicControl(Owner)
{
   FBitmap=NULL;
   FBitmap=new Graphics::TBitmap();
	FImageStyle=ipSingle;
   FXPosition=0;
   FYPosition=0;
	Width=100;
	Height=36;
   Caption="";
}
//---------------------------------------------------------------------------
 __fastcall TImagePanel::~TImagePanel()
{
 	delete FBitmap;
   FBitmap=NULL;
}
//---------------------------------------------------------------------------
namespace Imagepanel
{
	void __fastcall Register()
	{
		TComponentClass classes[1] = {__classid(TImagePanel)};
		RegisterComponents("Leunen", classes, 0);
	}
}
//---------------------------------------------------------------------------
void __fastcall TImagePanel::Paint(void)
{
  //Paint Rect around control
  Canvas->Pen->Style=psSolid;
  Canvas->Pen->Color=clBlack;
  Canvas->LineTo(Width-1,0);
  Canvas->Pen->Color=clWhite;
  Canvas->LineTo(Width-1,Height-1);
  Canvas->LineTo(0,Height-1);
  Canvas->Pen->Color=clBlack;
  Canvas->LineTo(0,0);

  if(FBitmap->Modified && ValidBmp)
  {
    tmpBitmap=new Graphics::TBitmap();
    tmpBitmap->Assign(FBitmap);
    if(ValidBmp && FBitmap->Modified)
    {
      int i,j,bmpWidth,bmpHeight;
      TRect	rect;
      rect=ClientRect;
      rect.Top++;
      rect.Right--;
      rect.Bottom--;
      rect.Left++;
      switch ((int)FImageStyle)
      {
        case ipSingle:
          if(tmpBitmap->Width>rect.Right-FXPosition)
              bmpWidth=rect.Right-FXPosition;
          else bmpWidth=tmpBitmap->Width;
          if(tmpBitmap->Height>rect.Bottom-FYPosition)
              bmpHeight=rect.Bottom-FYPosition;
          else bmpHeight=tmpBitmap->Height;
            ::BitBlt(Canvas->Handle,
                     FXPosition,
                     FYPosition,
                     bmpWidth,
                     bmpHeight,
                     tmpBitmap->Canvas->Handle,
                     0,
                     0,
                     SRCCOPY);
          break;

        case ipStretch:
          Canvas->StretchDraw(rect,tmpBitmap);
          break;

        case ipTile:
          for(i=rect.Top;i<rect.Bottom;i+=tmpBitmap->Height)
          {
            for(j=rect.Left;j<rect.Right;j+=tmpBitmap->Width)
            {
              if(j<rect.Right-tmpBitmap->Width)bmpWidth=tmpBitmap->Width;
              else bmpWidth=rect.Right-j;
              if(i<rect.Bottom-tmpBitmap->Height)bmpHeight=tmpBitmap->Height;
              else bmpHeight=rect.Bottom-i;
              ::BitBlt(Canvas->Handle,
                        j,
                        i,
                        bmpWidth,
                        bmpHeight,
                        tmpBitmap->Canvas->Handle,
                        0,
                        0,
                        SRCCOPY);
              }
            }
      }
    }
    delete tmpBitmap;
  }
}
//---------------------------------------------------------------------------
void __fastcall TImagePanel::SetBitmap(Graphics::TBitmap *ABitmap)
{
	if (ABitmap!=NULL)ValidBmp=true;
  else ValidBmp=false;
	FBitmap->Assign(ABitmap);
   Repaint();
}
//---------------------------------------------------------------------------
void __fastcall TImagePanel::SetXPos(int AXPosition)
{
	FXPosition=AXPosition;
   Repaint();
}
//---------------------------------------------------------------------------
void __fastcall TImagePanel::SetYPos(int AYPosition)
{
	FYPosition=AYPosition;
   Repaint();
}
//---------------------------------------------------------------------------
void __fastcall TImagePanel::SetImageStyle(TImageDrawStyle AImageStyle)
{
	FImageStyle=AImageStyle;
   Repaint();
}
//---------------------------------------------------------------------------
